<TS language="it" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Informazioni su Gridcoin</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Crea un nuovo indirizzo</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copia negli appunti l'indirizzo attualmente selezionato</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Mostra &amp;QR Code</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Firma un messaggio per dimostrare di possedere un indirizzo Gridcoin</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Firma &amp;Messaggio</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Verificare un messaggio per assicurarsi che sia stato firmato con un indirizzo Gridcoin specificato</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifica Messaggio</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Rimuove dalla lista l'indirizzo attualmente selezionato</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Rubrica</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Questi sono i tuoi indirizzi Gridcoin per ricevere pagamenti. Potresti volerne associare uno diverso per ogni mittente in modo da tener traccia di chi ti sta pagando.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copia &amp;Etichetta</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Esporta Dati Rubrica</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Errore durante l'esportazione</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Impossibile scrivere sul file %1.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etichetta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nessuna etichetta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Finestra passphrase</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Inserisci la passphrase</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nuova passphrase</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ripeti la nuova passphrase</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>Serve a disabilitare il semplice invio di denaro quando l'account del sistema operativo è compromesso. Non fornisce alcuna sicurezza reale.</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Solo per lo staking</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Inserisci la nuova passphrase per il portamonete.&lt;br/&gt;Si consiglia di utilizzare &lt;b&gt;almeno dieci caratteri casuali&lt;/b&gt; oppure &lt;b&gt;otto o più parole&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Cifra il portamonete</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Questa operazione necessita della passphrase per sbloccare il portamonete.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Sblocca il portamonete</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Cambia la passphrase</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Inserisci la vecchia e la nuova passphrase per il portamonete.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Conferma la cifratura del portamonete</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Attenzione: se si cifra il portamonete e si perde la passphrase, &lt;b&gt;TUTTO IL DENARO ANDRA' PERDUTO&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Si è sicuri di voler cifrare il portamonete?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Portamonete cifrato</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>Gridcoin ora si chiuderà per concludere il processo di cifratura. Ricorda che cifrare il portamonete non protegge il tuo denaro dal furto ad opera di malware che infettano il tuo computer.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>IMPORTANTE: qualsiasi backup del portamonete effettuato precedentemente dovrebbe essere sostituito con il file del portamonete criptato appena generato. Per ragioni di sicurezza, i backup precedenti del file del portamonete non criptato diventeranno inutili non appena inizierai ad utilizzare il nuovo portamonete criptato.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Il processo di cifratura del tuo portafogli è fallito</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Cifratura del portamonete fallita a causa di un errore interno. Il portamonete non è stato cifrato.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Le passphrase inserite non corrispondono.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Sbloccaggio del portafoglio fallito</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>La frase inserita per decriptare il tuo portamonete non è corretta.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Passphrase del portamonete modificata con successo.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Attenzione: tasto Blocco Maiuscole attivo!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
        <translation>Si è verificato un errore irreversibile. Gridcoin non può più continuare in sicurezza e verrà chiuso.</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Portamonete</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Sintesi</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Mostra lo stato generale del portamonete</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Invia</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Invia denaro ad un indirizzo Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Ricevi</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Mostra l'elenco degli indirizzi per ricevere i pagamenti</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Mostra la cronologia delle transazioni</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Modifica l'elenco degli indirizzi e delle etichette memorizzati</translation>
    </message>
    <message>
        <source>&amp;Voting</source>
        <translation>&amp;Voto</translation>
    </message>
    <message>
        <source>Voting</source>
        <translation>Voto</translation>
    </message>
    <message>
        <source>Web Site</source>
        <translation>Sito Web</translation>
    </message>
    <message>
        <source>&amp;Web Site</source>
        <translation>&amp;Sito Web</translation>
    </message>
    <message>
        <source>Gridcoin rewards distributed computing with BOINC</source>
        <translation>Gridcoin ricompensa il calcolo distribuito con BOINC</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Chiudi applicazione</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>&amp;Informazioni su Gridcoin</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Mostra informazioni su Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Diagnostics</source>
        <translation>&amp;Diagnostica</translation>
    </message>
    <message>
        <source>Diagnostics</source>
        <translation>Diagnostica</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opzioni...</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>Modifica le opzioni di configurazione per Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Mostra / Nascondi</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Cifra il portamonete...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Cambia passphrase...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Cambia la passphrase utilizzata per la cifratura del portamonete</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>&amp;Sblocca il portamonete...</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Sblocca il portamonete</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Cifra il portamonete</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Cifra il portamonete</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Firma &amp;messaggio...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifica messaggio...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Esporta...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Esporta su file i dati contenuti nella tabella corrente</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>Finestra di &amp;debug</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Apri la console di debug e diagnostica</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Client Gridcoin</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Aggiornato</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>In aggiornamento...</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>L'ultimo blocco ricevuto è stato generato %1.</translation>
    </message>
    <message>
        <source>This transaction is over the size limit.  You can still send it for a fee of %1, which goes to the nodes that process your transaction and helps to support the network.  Do you want to pay the fee?</source>
        <translation>Questa transazione supera il limite di dimensioni.  Puoi comunque inviarla ad un costo di %1, che andranno ai nodi che elaboreranno la tua transazione e aiuteranno a supportare la rete.  Vuoi pagare la commissione?</translation>
    </message>
    <message>
        <source>Confirm transaction fee</source>
        <translation>Conferma la commissione di transazione</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transazione inviata</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transazione ricevuta</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>Gestione URI</translation>
    </message>
    <message>
        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
        <translation>L'URI non può essere analizzato! Ciò può essere causato da un indirizzo Gridcoin non valido o da parametri URI non validi.</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Il portamonete è &lt;b&gt;cifrato&lt;/b&gt; ed attualmente &lt;b&gt;bloccato&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Backup Portamonete</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Dati Portamonete (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Backup Fallito</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to the new location.</source>
        <translation>Si è verificato un errore durante il tentativo di salvare i dati del portafogli nella nuova posizione.</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Avviso di rete</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Quantità:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Byte:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Importo:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Commissione:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Dopo Commissione:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Resto:</translation>
    </message>
    <message>
        <source>Tree &amp;mode</source>
        <translation>&amp;Modalità albero</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Importo</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Conferme</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confermato</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etichetta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copia l'indirizzo</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copia l'etichetta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia l'importo</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copia l'ID transazione</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copia quantità</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copia commissione</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copia dopo commissione</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copia byte</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copia low output</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copia resto</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>si</translation>
    </message>
    <message>
        <source>This label turns red, if the transaction size is bigger than 10000 bytes.

 This means a fee of at least %1 per kb is required.

 Can vary +/- 1 Byte per input.</source>
        <translation>Questa etichetta diventa rossa se la dimensione della transazione è maggiore di 10000 byte.

 Ciò significa che è richiesta una commissione di almeno %1 per kb.

 Può variare di +/- 1 Byte per input.</translation>
    </message>
    <message>
        <source>This label turns red, if any recipient receives an amount smaller than %1.

 This means a fee of at least %2 is required. 

 Amounts below 0.546 times the minimum relay fee are shown as DUST.</source>
        <translation>Questa etichetta diventa rossa se un destinatario riceve un importo inferiore a %1.

 Ciò significa che è richiesta una commissione di almeno %2.

 Gli importi inferiori a 0.546 volte la commissione minima del relay sono indicati come DUST.</translation>
    </message>
    <message>
        <source>This label turns red, if the change is smaller than %1.

 This means a fee of at least %2 is required.</source>
        <translation>Questa etichetta diventa rossa se il resto è minore di %1.

 Ciò significa che è richiesta una commissione di almeno %2.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nessuna etichetta)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>resto da %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(resto)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Modifica l'indirizzo</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etichetta</translation>
    </message>
    <message>
        <source>The label associated with this address book entry</source>
        <translation>L'etichetta associata a questa voce della rubrica</translation>
    </message>
    <message>
        <source>The address associated with this address book entry. This can only be modified for sending addresses.</source>
        <translation>L'indirizzo associato a questa voce della rubrica. Può essere modificato solo per gli indirizzi d'invio.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Indirizzo</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nuovo indirizzo di ricezione</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nuovo indirizzo d'invio</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Modifica indirizzo di ricezione</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Modifica indirizzo d'invio</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Gridcoin address.</source>
        <translation>L'indirizzo inserito "%1" non è un indirizzo Gridcoin valido.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>L'indirizzo inserito "%1" è già in rubrica.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Impossibile sbloccare il portamonete.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Generazione della nuova chiave non riuscita.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>versione</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Utilizzo:</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>opzioni della riga di comando</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Principale</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Rete</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mappa le porte tramite &amp;UPnP</translation>
    </message>
    <message>
        <source>Reser&amp;ve</source>
        <translation>&amp;Preserva</translation>
    </message>
    <message>
        <source>Automatically start Gridcoin after logging in to the system.</source>
        <translation>Avvia automaticamente Gridcoin dopo il login di sistema.</translation>
    </message>
    <message>
        <source>&amp;Start Gridcoin on system login</source>
        <translation>&amp;Avvia Gridcoin al login</translation>
    </message>
    <message>
        <source>Automatically open the Gridcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Apri automaticamente la porta del client Gridcoin sul router. Funziona solo quando il tuo router supporta UPnP e quest'ultimo è abilitato.</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. 127.0.0.1)</source>
        <translation>Indirizzo IP del proxy (es. 127.0.0.1)</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Porta:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Porta del proxy (ad es. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Riduci ad icona invece di uscire dall'applicazione quando la finestra viene chiusa. Quando questa opzione è attivata, l'applicazione verrà chiusa solo dopo aver selezionato Esci nel menu.</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting Gridcoin.</source>
        <translation>La lingua dell'interfaccia utente può essere impostata qui. Questa impostazione avrà effetto dopo il riavvio di Gridcoin.</translation>
    </message>
    <message>
        <source>Style:</source>
        <translation>Stile:</translation>
    </message>
    <message>
        <source>Choose a stylesheet to change the look of the wallet.</source>
        <translation>Scegli uno stile per cambiare look al portamonete.</translation>
    </message>
    <message>
        <source>Whether to show Gridcoin addresses in the transaction list or not.</source>
        <translation>Indica se mostrare gli indirizzi Gridcoin nell'elenco delle transazioni o meno.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Mostra gli indirizzi nella lista delle transazioni</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Finestra</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Applica</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Mostra solo un'icona nella tray bar quando si riduce ad icona.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimizza nella tray bar invece che sulla barra delle applicazioni</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimizza alla chiusura</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Aspetto</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Lingua Interfaccia utente:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unità di misura degli importi:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Scegli l'unità di suddivisione predefinita da utilizzare per l'interfaccia e per l'invio di Gridcoin.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>default</source>
        <translation>predefinito</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <source>This setting will take effect after restarting Gridcoin.</source>
        <translation>Queste modifiche avranno effetto dopo aver riavviato Gridcoin.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>L'indirizzo proxy che hai fornito non è valido.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Disponibile:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Il tuo saldo spendibile attuale</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Immaturo:</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Portamonete</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Gridcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Le informazioni visualizzate potrebbero non essere aggiornate. Il tuo portamonete si sincronizza automaticamente con la rete Gridcoin dopo aver stabilito una connessione, ma questo processo non è ancora stato completato.</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the current balance</source>
        <translation>Totale delle transazioni che devono ancora essere confermate e che non contano ancora per il saldo attuale</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Totale:</translation>
    </message>
    <message>
        <source>Total mined coins that have not yet matured.</source>
        <translation>Totale monete minate che non sono ancora maturate.</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Il tuo saldo totale attuale</translation>
    </message>
    <message>
        <source>Blocks:</source>
        <translation>Blocchi:</translation>
    </message>
    <message>
        <source>Difficulty:</source>
        <translation>Difficoltà:</translation>
    </message>
    <message>
        <source>Net Weight:</source>
        <translation>Peso della rete:</translation>
    </message>
    <message>
        <source>Magnitude:</source>
        <translation>Magnitudine:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Stato:</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>QR Code Dialog</source>
        <translation>Finestra QR Code</translation>
    </message>
    <message>
        <source>Request Payment</source>
        <translation>Richiesta di pagamento</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Etichetta:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Messaggio:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Importo:</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Salva come...</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Errore nella codifica dell'URI nel codice QR.</translation>
    </message>
    <message>
        <source>The entered amount is invalid, please check.</source>
        <translation>L'importo inserito non è valido, si prega di controllare.</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>L'URI risultante è troppo lungo, prova a ridurre il testo nell'etichetta / messaggio.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Salva codice QR</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Versione client</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informazioni</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Ora di avvio</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Numero di connessioni</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Numero attuale di blocchi</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Ora del blocco più recente</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Apri</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Cancella</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Traffico di Rete</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Totali</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Entrata:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Uscita:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>File log del debug</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Pulisci console</translation>
    </message>
    <message>
        <source>Gridcoin - Debug Console</source>
        <translation>Gridcoin - Console di Debug</translation>
    </message>
    <message>
        <source>Boost version</source>
        <translation>Versione Boost</translation>
    </message>
    <message>
        <source>Network:</source>
        <translation>Rete:</translation>
    </message>
    <message>
        <source>On testnet</source>
        <translation>Su testnet</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Numero totale stimato di blocchi</translation>
    </message>
    <message>
        <source>Open the Gridcoin debug log file from the current data directory. This can take a few seconds for large log files.</source>
        <translation>Apri il file di log di debug di Gridcoin dalla cartella dati corrente. Questo può richiedere alcuni secondi per i file di log di grandi dimensioni.</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Opzioni della riga di comando</translation>
    </message>
    <message>
        <source>Show the Gridcoin help message to get a list with possible Gridcoin command-line options.</source>
        <translation>Mostra il messaggio di aiuto di Gridcoin per ottenere una lista con le possibili opzioni da riga di comando di Gridcoin.</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>&amp;Mostra</translation>
    </message>
    <message>
        <source>OpenSSL version</source>
        <translation>Versione OpenSSL</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Nome del client</translation>
    </message>
    <message>
        <source>Welcome to the Gridcoin RPC console! </source>
        <translation>Benvenuto nella console RPC di Gridcoin! </translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Usa le frecce direzionali per scorrere la cronologia e &lt;b&gt;Ctrl-L&lt;/b&gt; per cancellarla.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Scrivi &lt;b&gt;help&lt;/b&gt; per un riassunto dei comandi disponibili.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Invia Gridcoin</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Input...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>selezionato automaticamente</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fondi insufficienti!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Quantità:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Byte:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Importo:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Commissione:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Dopo Commissione:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Resto</translation>
    </message>
    <message>
        <source>custom change address</source>
        <translation>indirizzo di resto personalizzato</translation>
    </message>
    <message>
        <source>Remove all transaction fields</source>
        <translation>Rimuovi tutti i campi della transazione</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Invia simultaneamente a più beneficiari</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;Aggiungi beneficiario</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Cancella &amp;tutto</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Conferma l'azione di invio</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Invia</translation>
    </message>
    <message>
        <source>Enter a Gridcoin address (e.g. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</source>
        <translation>Inserisci un indirizzo Gridcoin (es. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copia quantità</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia importo</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copia commissione</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copia dopo commissione</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copia byte</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copia low output</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copia resto</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; to %2 (%3)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; a %2 (%3)</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Conferma la spedizione di Gridcoin</translation>
    </message>
    <message>
        <source>Are you sure you want to send %1?</source>
        <translation>Sei sicuro di voler inviare %1?</translation>
    </message>
    <message>
        <source> and </source>
        <translation> e </translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>L'indirizzo del beneficiario non è valido, per cortesia ricontrolla.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>L'importo da pagare dev'essere maggiore di 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>L'importo è superiore al saldo attuale.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Il totale è superiore al saldo attuale includendo la commissione di %1.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Trovato un indirizzo doppio, si può spedire solo una volta a ciascun indirizzo in una singola operazione.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed.</source>
        <translation>Errore: Creazione transazione fallita.</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected. This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Errore: la transazione è stata rifiutata. Questo può accadere se alcune monete nel tuo portafoglio sono già state spese, ad esempio se hai usato una copia di wallet.dat e le monete sono state spese nella copia ma non sono state contrassegnate come spese qui.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nessuna etichetta)</translation>
    </message>
    <message>
        <source>WARNING: Invalid Gridcoin address</source>
        <translation>ATTENZIONE: Indirizzo Gridcoin non valido</translation>
    </message>
    <message>
        <source>WARNING: unknown change address</source>
        <translation>ATTENZIONE: indirizzo di resto sconosciuto</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Importo:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Paga &amp;a:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Messaggio:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etichetta:</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <source>The address to send the payment to  (e.g. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</source>
        <translation>L'indirizzo a cui inviare il pagamento (es. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Incolla l'indirizzo dagli appunti</translation>
    </message>
    <message>
        <source>Send Custom Message to a Gridcoin Recipient</source>
        <translation>Invia un messaggio personalizzato a un beneficiario Gridcoin</translation>
    </message>
    <message>
        <source>Choose address from address book</source>
        <translation>Scegli l'indirizzo dalla rubrica</translation>
    </message>
    <message>
        <source>Remove this recipient</source>
        <translation>Rimuovi questo beneficiario</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Inserisci un'etichetta per questo indirizzo per aggiungerlo alla rubrica</translation>
    </message>
    <message>
        <source>Enter a Gridcoin address (e.g. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</source>
        <translation>Inserisci un indirizzo Gridcoin (es. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Firme - Firma / Verifica un messaggio</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Firma Messaggio</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Puoi firmare messeggi con i tuoi indirizzi per dimostrare che sono tuoi. Fai attenzione a non firmare niente di vago, visto che gli attacchi di phishing potrebbero cercare di spingerti a mettere la tua firma su di loro. Firma solo dichiarazioni completamente dettagliate con cui sei d'accordo.</translation>
    </message>
    <message>
        <source>The address to sign the message with (e.g. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</source>
        <translation>L'indirizzo con cui firmare il messaggio (es. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>Scegli un indirizzo dalla rubrica</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Incolla l'indirizzo dagli appunti</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Inserisci qui il messaggio che vuoi firmare</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Copia la firma corrente negli appunti</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Gridcoin address</source>
        <translation>Firma il messaggio per dimostrare che sei il proprietario di questo indirizzo di Gridcoin</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Firma &amp;Messaggio</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Reimposta tutti i campi della firma messaggio</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Cancella &amp;Tutto</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifica Messaggio</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Inserisci l'indirizzo per la firma, il messaggio (verifica di copiare esattamente anche i ritorni a capo, gli spazi, le tabulazioni, etc) e la firma qui sotto, per verificare il messaggio. Verifica che il contenuto della firma non sia più grande di quello del messaggio per evitare attacchi di tipo man-in-the-middle.</translation>
    </message>
    <message>
        <source>The address the message was signed with (e.g. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</source>
        <translation>L'indirizzo con cui è stato firmato il messaggio (es. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Gridcoin address</source>
        <translation>Verificare il messaggio per assicurarsi che sia stato firmato con l'indirizzo Gridcoin specificato</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Reimposta tutti i campi della verifica messaggio</translation>
    </message>
    <message>
        <source>Enter a Gridcoin address (e.g. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</source>
        <translation>Inserisci un indirizzo Gridcoin (es. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Clicca "Firma il messaggio" per ottenere la firma</translation>
    </message>
    <message>
        <source>Enter Gridcoin signature</source>
        <translation>Inserisci la firma di Gridcoin</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>L'indirizzo inserito non è valido.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Per favore controlla l'indirizzo e riprova.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>L'indirizzo Gridcoin inserito non è associato a nessuna chiave.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Sblocco del portamonete annullato.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>La chiave privata per l'indirizzo inserito non è disponibile.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Firma messaggio fallita.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Messaggio firmato.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Non è stato possibile decodificare la firma.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Per favore controlla la firma e riprova.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>La firma non corrisponde al sunto del messaggio.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Verifica messaggio fallita.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Messaggio verificato.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Aperto fino a %1</translation>
    </message>
    <message>
        <source>conflicted</source>
        <translation>in conflitto</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/non confermato</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 conferme</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, non è stato ancora trasmesso con successo</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Sorgente</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Da</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>sconosciuto</translation>
    </message>
    <message>
        <source>To</source>
        <translation>A</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>proprio indirizzo</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etichetta</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Credito</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>non accettato</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debito</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Commissione transazione</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Importo netto</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Messaggio</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Commento</translation>
    </message>
    <message>
        <source>Gridcoin generated coins must mature 110 blocks before they can be spent. When you generated this block, it was broadcast to the network to be added to the block chain. If it fails to get into the chain, its state will change to "not accepted" and it won't be spendable. This may occasionally happen if another node generates a block within a few seconds of yours.</source>
        <translation>Le monete generate da Gridcoin devono maturare 110 blocchi prima che possano essere spese. Quando hai generato questo blocco, è stato trasmesso alla rete per essere aggiunto alla catena di blocchi. Se non riuscirà ad entrare nella catena, il suo stato cambierà in "non accettato" e non sarà spendibile. Questo può accadere occasionalmente se un altro nodo genera un blocco entro pochi secondi dal tuo.</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Importo</translation>
    </message>
    <message>
        <source>true</source>
        <translation>vero</translation>
    </message>
    <message>
        <source>false</source>
        <translation>falso</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Dettagli transazione</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Questo pannello mostra una descrizione dettagliata della transazione</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;hiudi</translation>
    </message>
</context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Importo</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Aperto fino a %1</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Non confermato</translation>
    </message>
    <message>
        <source>Confirming (%1 of %2 recommended confirmations)&lt;br&gt;</source>
        <translation>In conferma (%1 su %2 conferme raccomandate)&lt;br&gt;</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Confermato (%1 conferme)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>In conflitto</translation>
    </message>
    <message>
        <source>Immature (%1 confirmations, will be available after %2)&lt;br&gt;</source>
        <translation>Immaturo (%1 conferme, sarà disponibile dopo %2)&lt;br&gt;</translation>
    </message>
    <message>
        <source>This block was not received by any other nodes&lt;br&gt; and will probably not be accepted!</source>
        <translation>Questo blocco non è stato ricevuto da nessun altro nodo&lt;br&gt; e probabilmente non sarà accettato!</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generato, ma non accettato</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ricevuto tramite</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Ricevuto da</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Spedito a</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pagamento a te stesso</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(n/d)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Stato della transazione. Passare con il mouse su questo campo per vedere il numero di conferme.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Data e ora in cui la transazione è stata ricevuta.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipo di transazione.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Indirizzo di destinazione della transazione.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Importo rimosso o aggiunto al saldo.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Oggi</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Questa settimana</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Questo mese</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Ultimo mese</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Quest'anno</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Intervallo...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ricevuto tramite</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Spedito a</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>A te</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Ottenuto dal mining</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altro</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Importo minimo</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copia l'indirizzo</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copia l'etichetta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia l'importo</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copia l'ID transazione</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Modifica l'etichetta</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Mostra i dettagli della transazione</translation>
    </message>
    <message>
        <source>Export Transaction Data</source>
        <translation>Esporta dati transazione</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confermato</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etichetta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Importo</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Esporta errori</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Impossibile scrivere sul file %1.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Intervallo:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>a</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>Invio...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Errore riscontrato durante l'impostazione della porta RPC %u per l'ascolto su IPv6, torno su IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Errore riscontrato durante l'impostazione della porta RPC %u per l'ascolto su IPv4: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Utilizzo:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Lista comandi
</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Aiuto su un comando
</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Attenzione: -paytxfee è molto alta. Questa è la commissione che si paga quando si invia una transazione.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Attenzione: wallet.dat corrotto, dati salvati! Il wallet.dat originale salvato come wallet.{timestamp}.bak in %s; se il tuo bilancio o le transazioni non sono corrette dovresti ripristinare da un backup.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Attenzione: errore di lettura di wallet.dat!  Tutte le chiavi lette correttamente, ma i dati delle transazioni o le voci in rubrica potrebbero mancare o non essere corretti.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed  </source>
        <translation>Errore: creazione della transazione fallita  </translation>
    </message>
    <message>
        <source>Error: The transaction was rejected.  This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Errore: la transazione è stata rifiutata. Questo può accadere se alcune monete nel tuo portafoglio sono già state spese, ad esempio se hai usato una copia di wallet.dat e le monete sono state spese nella copia ma non sono state contrassegnate come spese qui.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Nessuna porta disponibile per l'ascolto. Usa -listen=0 se vuoi procedere comunque.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Per usare l'opzione %s</translation>
    </message>
    <message>
        <source>%s, you must set a rpcpassword in the configuration file:
 %s
It is recommended you use the following random password:
rpcuser=gridcoinrpc
rpcpassword=%s
(you do not need to remember this password)
The username and password MUST NOT be the same.
If the file does not exist, create it with owner-readable-only file permissions.
It is also recommended to set alertnotify so you are notified of problems;
for example: alertnotify=echo %%s | mail -s "Gridcoin Alert" admin@foo.com
</source>
        <translation>%s, devi impostare una rpcpassword nel file di configurazione:
 %s
Si consiglia di utilizzare la seguente password casuale:
rpcuser=gridcoinrpc
rpcpassword=%s
(non è necessario ricordare questa password)
L'username e la password NON DEVONO essere uguali.
Se il file non esiste, crealo con i permessi di amministratore.
Si consiglia inoltre di impostare alertnotify in modo da essere avvisati di eventuali problemi;
per esempio: alertnotify=echo %%s | mail -s "Gridcoin Alert" admin@foo.com
</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Devi settare rpcpassword=&lt;password&gt; nel file di configurazione: %s Se il file non esiste, crealo con i permessi di amministratore.</translation>
    </message>
    <message>
        <source>Gridcoin version</source>
        <translation>Versione Gridcoin</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Importo non valido per -paytxfee=&lt;importo&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -mininput=&lt;amount&gt;: '%s'</source>
        <translation>Importo non valido per -mininput=&lt;importo&gt;: '%s'</translation>
    </message>
    <message>
        <source>Initialization sanity check failed. Gridcoin is shutting down.</source>
        <translation>Verifica d'integrita di inizializzazione fallita. Gridcoin verrà chiuso.</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>Il portamonete %s è fuori dalla cartella dati %s.</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>Verifica dell'integrità del database...</translation>
    </message>
    <message>
        <source>Error initializing database environment %s! To recover, BACKUP THAT DIRECTORY, then remove everything from it except for wallet.dat.</source>
        <translation>Errore durante l'inizializzazione dell'ambiente del database %s! Per ripristinare, FARE IL BACKUP DI QUELLA CARTELLA, poi rimuoverne tutto il contenuto tranne wallet.dat.</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat corrotto, salvataggio fallito</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Indirizzo -proxy non valido: '%s'</translation>
    </message>
    <message>
        <source>Invalid -tor address: '%s'</source>
        <translation>Indirizzo -tor non valido: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Impossibile risolvere indirizzo -bind: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Impossibile risolvere indirizzo -externalip: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -reservebalance=&lt;amount&gt;</source>
        <translation>Importo non valido per -reservebalance=&lt;importo&gt;</translation>
    </message>
    <message>
        <source>Error loading blkindex.dat</source>
        <translation>Errore durante il caricamento di blkindex.dat</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Errore caricamento wallet.dat: portamonete corrotto</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet requires newer version of Gridcoin</source>
        <translation>Errore durante il caricamento di wallet.dat: il portamonete richiede una versione più recente di Gridcoin</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart Gridcoin to complete</source>
        <translation>Il portamonete doveva essere riscritto: riavviare Gridcoin per completare</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Errore caricamento wallet.dat</translation>
    </message>
    <message>
        <source>Importing bootstrap blockchain data file.</source>
        <translation>Importazione del file di dati bootstrap blockchain.</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Caricamento indirizzi...</translation>
    </message>
    <message>
        <source>Error: could not start node</source>
        <translation>Errore: impossibile avviare il nodo</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. Gridcoin is probably already running.</source>
        <translation>Impossibile collegarsi alla %s su questo computer. Gridcoin è probabilmente già in esecuzione.</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Impossibile collegarsi alla %s su questo computer (bind returned error %d, %s)</translation>
    </message>
    <message>
        <source>Error: Wallet locked, unable to create transaction  </source>
        <translation>Errore: portamonete bloccato, impossibile creare la transazione  </translation>
    </message>
    <message>
        <source>Error: Wallet unlocked for staking only, unable to create transaction.</source>
        <translation>Errore: portamonete sbloccato solo per lo staking, impossibile creare la transazione.</translation>
    </message>
    <message>
        <source>Error: This transaction requires a transaction fee of at least %s because of its amount, complexity, or use of recently received funds  </source>
        <translation>Errore: questa transazione richiede una commissione di transazione di almeno %s a causa del suo importo, della sua complessità o dell'utilizzo di fondi ricevuti di recente  </translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Invio...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Importo non valido</translation>
    </message>
    <message>
        <source>Warning: Please check that your computer's date and time are correct! If your clock is wrong Gridcoin will not work properly.</source>
        <translation>Attenzione: verificare che la data e l'ora del computer siano corrette! Se il tuo orologio è sbagliato, Gridcoin non funzionerà correttamente.</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>Attenzione: lo spazio su disco è ridotto!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Rete sconosciuta specificata in -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Fondi insufficienti</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Caricamento dell'indice dei blocchi...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Caricamento portamonete...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Non è possibile scrivere l'indirizzo predefinito</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Ripetizione scansione...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Caricamento completato</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
</TS>